package Task::CPANAuthors::STRO;

use strict;
use warnings;

our $VERSION = '2009.0521';

1;

=head1 NAME

Task::CPANAuthors::STRO

=head1 SYNOPSIS

 perl -MCPAN -e 'install Task::CPANAuthors::STRO'

=head1 CONTENTS

Data::Define

FindBin::Real

FTN::Address

FTN::Nodelist

Lingua::Cyrillic::Translit::ICAO

Lingua::Multinational::Translit::ICAO

Lingua::RU::Jcuken

Lingua::EN::Jcuken

Prompt::Timeout

Text::Compare

Win32::Uptime

=head1 DESCRIPTION

Task:: of modules I maintain.

=head1 AUTHOR

Serguei Trouchelle E<lt>F<stro@cpan.org>E<gt>

=cut 
